# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

accessKey: Optional[str]
"""
API Key used to authenticate with the rancher server
"""

apiUrl: Optional[str]
"""
The URL to the rancher API
"""

bootstrap: bool
"""
Bootstrap rancher server
"""

caCerts: Optional[str]
"""
CA certificates used to sign rancher server tls certificates. Mandatory if self signed tls and insecure option false
"""

insecure: bool
"""
Allow insecure connections to Rancher. Mandatory if self signed tls and not ca_certs provided
"""

retries: Optional[int]
"""
Rancher connection retries
"""

secretKey: Optional[str]
"""
API secret used to authenticate with the rancher server
"""

timeout: Optional[str]
"""
Rancher connection timeout (retry every 5s). Golang duration format, ex: "60s"
"""

tokenKey: Optional[str]
"""
API token used to authenticate with the rancher server
"""

